@@ -18,7 +18,9 @@ ResolverType = T.TypeVar("ResolverType", bound="Resolver")
 BaseModelType = T.TypeVar("BaseModelType", bound=BaseModel)
 
 
-def get_fields_and_nested_fields(cls: T.Type[BaseModelType]) -> T.List[str]:
+def get_fields_and_nested_fields(
+    cls: T.Type[BaseModelType], include_typename: bool = True
+) -> T.List[str]:
     field_names: T.List[str] = []
     for field_name, model_field in cls.__fields__.items():
         t = model_field.type_
@@ -28,7 +30,9 @@ def get_fields_and_nested_fields(cls: T.Type[BaseModelType]) -> T.List[str]:
             )
         else:
             field_names.append(field_name)
-    return [*field_names, "__typename"]
+    if include_typename:
+        return [*field_names, "__typename"]
+    return field_names
 
 
 class Resolver(BaseModel, T.Generic[NodeType]):
