@@ -242,31 +242,31 @@ class Artist(Node[ArtistInsert]):
         model_name = "Artist"
         client = client
         updatable_fields: T.Set[str] = {
-            "last_updated",
-            "migration_version",
-            "last_triggered_at",
-            "created_at",
-            "cover_image",
-            "admin_details",
-            "published",
             "bio",
+            "media",
+            "band_configuration",
+            "created_at",
+            "category",
+            "slug",
+            "contact_information",
+            "cover_image",
+            "last_backend_updated",
+            "spotify_id",
+            "last_triggered_at",
+            "subgenres",
+            "name",
+            "venue_take_percentages",
+            "migration_version",
+            "published",
+            "admin_details",
             "connect_account_id",
             "social_media",
-            "slug",
-            "name",
-            "profile_image",
-            "category",
-            "version",
-            "last_backend_updated",
-            "contact_information",
             "last_redis_refreshed",
-            "spotify_id",
-            "venue_take_percentages",
-            "band_configuration",
-            "subgenres",
-            "media",
+            "version",
+            "last_updated",
+            "profile_image",
         }
-        exclusive_fields: T.Set[str] = {"beatgig_id", "id", "slug"}
+        exclusive_fields: T.Set[str] = {"id", "slug", "beatgig_id"}
 
 
 class ArtistResolver(Resolver[Artist]):
@@ -393,11 +393,11 @@ class Booking(Node[BookingInsert]):
         client = client
         updatable_fields: T.Set[str] = {
             "negotiation_steps",
-            "start_time",
             "performance_length_mins",
             "created_at",
+            "start_time",
         }
-        exclusive_fields: T.Set[str] = {"beatgig_id", "id"}
+        exclusive_fields: T.Set[str] = {"id", "beatgig_id"}
 
 
 class BookingResolver(Resolver[Booking]):
@@ -432,8 +432,8 @@ Booking.GraphORM.resolver_type = BookingResolver
 class UserInsert(BaseModel):
     phone_number: str
     slug: str
-    firebase_id: str
     beatgig_id: str
+    firebase_id: str
     email: str
     created_at: datetime
     name: str
@@ -458,8 +458,8 @@ class UserInsert(BaseModel):
     _edgedb_conversion_map: T.ClassVar[T.Dict[str, str]] = {
         "phone_number": "std::str",
         "slug": "std::str",
-        "firebase_id": "std::str",
         "beatgig_id": "std::str",
+        "firebase_id": "std::str",
         "email": "std::str",
         "created_at": "std::datetime",
         "name": "std::str",
@@ -482,8 +482,8 @@ class User(Node[UserInsert]):
     id: UUID = Field(..., allow_mutation=False)
     phone_number: str = Field(..., allow_mutation=True)
     slug: str = Field(..., allow_mutation=True)
-    firebase_id: str = Field(..., allow_mutation=True)
     beatgig_id: str = Field(..., allow_mutation=False)
+    firebase_id: str = Field(..., allow_mutation=False)
     email: str = Field(..., allow_mutation=True)
     created_at: datetime = Field(..., allow_mutation=True)
     name: str = Field(..., allow_mutation=True)
@@ -504,8 +504,8 @@ class User(Node[UserInsert]):
         "id": "std::uuid",
         "phone_number": "std::str",
         "slug": "std::str",
-        "firebase_id": "std::str",
         "beatgig_id": "std::str",
+        "firebase_id": "std::str",
         "email": "std::str",
         "created_at": "std::datetime",
         "name": "std::str",
@@ -621,31 +621,30 @@ class User(Node[UserInsert]):
         model_name = "User"
         client = client
         updatable_fields: T.Set[str] = {
-            "last_updated",
-            "approved",
-            "email",
-            "referred_by_id",
-            "admin_permissions",
-            "last_triggered_at",
-            "profile_image",
+            "approval",
             "metadata",
+            "email",
             "user_type",
             "phone_number",
-            "user_role",
-            "admin_type",
-            "slug",
-            "name",
+            "admin_permissions",
             "default_state_abbr",
-            "approval",
-            "firebase_id",
+            "last_triggered_at",
+            "user_role",
+            "referred_by_id",
+            "name",
+            "slug",
             "created_at",
+            "admin_type",
+            "last_updated",
+            "profile_image",
+            "approved",
         }
         exclusive_fields: T.Set[str] = {
-            "id",
-            "phone_number",
-            "beatgig_id",
-            "slug",
             "firebase_id",
+            "phone_number",
+            "id",
+            "slug",
+            "beatgig_id",
         }
 
 
@@ -915,13 +914,13 @@ class Person(Node[PersonInsert]):
         model_name = "Person"
         client = client
         updatable_fields: T.Set[str] = {
-            "full_name",
-            "ordered_tags",
             "first_name",
-            "last_name",
             "tags",
+            "full_name",
+            "last_name",
             "slug",
             "created_at",
+            "ordered_tags",
         }
         exclusive_fields: T.Set[str] = {"id", "slug"}
 
@@ -1143,28 +1142,28 @@ class Venue(Node[VenueInsert]):
         model_name = "Venue"
         client = client
         updatable_fields: T.Set[str] = {
-            "last_updated",
-            "venue_type",
-            "logo",
-            "num_stages",
-            "place_id",
-            "website",
-            "created_at",
-            "display_images",
-            "social_media",
-            "slug",
-            "name",
-            "customer_id",
-            "capacity",
             "budget",
+            "created_at",
+            "logo",
+            "slug",
+            "place_id",
             "location",
+            "phone_number",
+            "production_and_venue_specs",
+            "display_images",
+            "name",
+            "capacity",
             "colors",
             "images",
-            "production_and_venue_specs",
             "genres_booked",
-            "phone_number",
+            "customer_id",
+            "website",
+            "social_media",
+            "venue_type",
+            "last_updated",
+            "num_stages",
         }
-        exclusive_fields: T.Set[str] = {"beatgig_id", "id", "slug"}
+        exclusive_fields: T.Set[str] = {"id", "slug", "beatgig_id"}
 
 
 class VenueResolver(Resolver[Venue]):
@@ -1270,14 +1269,14 @@ class Animal(Node[AnimalInsert]):
         client = client
         updatable_fields: T.Set[str] = {
             "description",
-            "age",
             "animal_type",
-            "public_id",
-            "slug",
             "name",
+            "slug",
             "created_at",
+            "age",
+            "public_id",
         }
-        exclusive_fields: T.Set[str] = {"id", "slug", "public_id"}
+        exclusive_fields: T.Set[str] = {"id", "public_id", "slug"}
 
 
 class AnimalResolver(Resolver[Animal]):
